# Nehushtan (נְחֻשְׁתָּן)

A toolkit for projects in Python

![PyPI](https://img.shields.io/pypi/v/nehushtan)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/nehushtan)
![PyPI - License](https://img.shields.io/pypi/l/nehushtan)
![PyPI - Downloads](https://img.shields.io/pypi/dm/nehushtan)

![https://www.jetbrains.com/community/opensource/#support](https://img.shields.io/badge/PyCharm-Licenses%20for%20Open%20Source%20Development-yellowgreen)

<img src="https://github.com/sinri/nehushtan/blob/master/icon.png?raw=true" width="64" height="64"></img>

> ipse dissipavit excelsa et contrivit statuas et succidit lucos confregitque serpentem aeneum quem fecerat Moses siquidem usque ad illud tempus filii Israhel adolebant ei incensum vocavitque eum Naasthan

License: MIT

## Category

### CLI

Help to handle the command line parameters.

### Helper

Provide an easier way to access to class, data, etc.

### Logging

Provide a solution for logging, other than the default.

### Mail

A package to support EMail related tasks.

### MySQL

Provide a high-to-low solution on MySQL access, with Model support.

### Queue

A designed framework for queue using `subprocess`. 

### Multi-Processing

Support for multiprocessing queue.